@@ -3,7 +3,7 @@
 /**
   * SquirrelMail Add Address Plugin
   * Copyright (c) 1999-2008 The SquirrelMail Project Team
-  * Copyright (c) 2008 Paul Lesniewski <paul@squirrelmail.org>,
+  * Copyright (c) 2008-2009 Paul Lesniewski <paul@squirrelmail.org>,
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -46,7 +46,7 @@ function add_address_init()
 
    if (!@include_once (SM_PATH . 'config/config_add_address.php'))
       if (!@include_once (SM_PATH . 'plugins/add_address/config.php'))
-         if (!@include_once (SM_PATH . 'plugins/add_address/config.sample.php'))
+         if (!@include_once (SM_PATH . 'plugins/add_address/config_default.php'))
             return FALSE;
 
    return TRUE;
@@ -55,7 +55,7 @@ function add_address_init()
    return load_config('add_address',
                       array('../../config/config_add_address.php',
                             'config.php',
-                            'config.sample.php'),
+                            'config_default.php'),
                       TRUE, TRUE);
 ----------- */
 
@@ -266,9 +266,8 @@ function add_address_auto_add_do($args)
 function add_address_link_do(&$links)
 {
 
-   global $message;
-   sqgetGlobalVar('mailbox',       $mailbox,       SQ_FORM);
-   sqgetGlobalVar('passed_id',     $passed_id,     SQ_FORM);
+   global $message, $passed_id;
+   sqgetGlobalVar('mailbox',   $mailbox,   SQ_FORM);
 
    // if no new addresses are in this message, no link is needed
    //
@@ -429,7 +428,8 @@ function aa_find_addresses($message, $mailbox=NULL, $passed_id=NULL,
       if (check_sm_version(1, 5, 2))
       {
          global $Email_RegExp_Match;
-         $email_regex = str_replace('/', '\\/', $Email_RegExp_Match);
+         //$email_regex = str_replace('/', '\\/', $Email_RegExp_Match);
+         $email_regex = $Email_RegExp_Match;
       }
       else
       {
